This is a package to simplify the initial literature search process in research. Please contact program author for details about use at alexcalder91@gmail.com

The user must first define a search on their library website with a focused and limited set of results (no more than 500). Once the desired search has been limited to 500 or less results, please copy the url to be pasted in the command line.

Then, initialize Search Buddy by opening the command terminal and typing: litsearch.

Search Buddy will prompt you to provide a brief name for the search. If the name is composed of multiple words, please connect them with an underscore. Not doing so may result in your search data not saving. Search Buddy will save your searches with a date stamp for reference.

Following this, Search Buddy will prompt you to paste the url for your search. Make sure you have a stable internet connection for at least the amount of time to completion estimated by the program. Estimated time is only an estimate. Actual time to completion will depend on several factors, including the quality of your internet speed, the number of search results, computer processing speed, etc.

The final output will be a .csv file containing the title, abstract, first author, and journal information for the articles returned from your search. This .csv can be converted to and excel file for further manipulation and data exploration. These data provide the user with a high-level overview of a narrowly defined domain of research literature. 